==> vtk-6.3.0-5-armv7h.pkg.tar.xz: vtk/vtkActor.java <==
// java wrapper for vtkActor object
//

package vtk;
import vtk.*;

public class vtkActor extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetActors_2(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_2(id0); }

  private native int RenderOpaqueGeometry_3(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_3(id0); }

  private native int RenderTranslucentPolygonalGeometry_4(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_4(id0); }

  private native int HasTranslucentPolygonalGeometry_5();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_5(); }

  private native void Render_6(vtkRenderer id0,vtkMapper id1);
  public void Render(vtkRenderer id0,vtkMapper id1)
    { Render_6(id0,id1); }

  private native void ShallowCopy_7(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_7(id0); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native void SetProperty_9(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_9(id0); }

  private native long GetProperty_10();
  public vtkProperty GetProperty() {
    long temp = GetProperty_10();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native long MakeProperty_11();
  public vtkProperty MakeProperty() {
    long temp = MakeProperty_11();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetBackfaceProperty_12(vtkProperty id0);
  public void SetBackfaceProperty(vtkProperty id0)
    { SetBackfaceProperty_12(id0); }

  private native long GetBackfaceProperty_13();
  public vtkProperty GetBackfaceProperty() {
    long temp = GetBackfaceProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetTexture_14(vtkTexture id0);
  public void SetTexture(vtkTexture id0)
    { SetTexture_14(id0); }

  private native long GetTexture_15();
  public vtkTexture GetTexture() {
    long temp = GetTexture_15();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void SetMapper_16(vtkMapper id0);
  public void SetMapper(vtkMapper id0)
    { SetMapper_16(id0); }

  private native long GetMapper_17();
  public vtkMapper GetMapper() {
    long temp = GetMapper_17();

    if (temp == 0) return null;
    return (vtkMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void GetBounds_18(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_18(id0); }

  private native double[] GetBounds_19();
  public double[] GetBounds()
    { return GetBounds_19(); }

  private native void ApplyProperties_20();
  public void ApplyProperties()
    { ApplyProperties_20(); }

  private native int GetMTime_21();
  public int GetMTime()
    { return GetMTime_21(); }

  private native int GetRedrawMTime_22();
  public int GetRedrawMTime()
    { return GetRedrawMTime_22(); }

  private native boolean GetSupportsSelection_23();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_23(); }

  public vtkActor() { super(); }

  public vtkActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkActor.java <==
// java wrapper for vtkActor object
//

package vtk;
import vtk.*;

public class vtkActor extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void GetActors_2(vtkPropCollection id0);
  public void GetActors(vtkPropCollection id0)
    { GetActors_2(id0); }

  private native int RenderOpaqueGeometry_3(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_3(id0); }

  private native int RenderTranslucentPolygonalGeometry_4(vtkViewport id0);
  public int RenderTranslucentPolygonalGeometry(vtkViewport id0)
    { return RenderTranslucentPolygonalGeometry_4(id0); }

  private native int HasTranslucentPolygonalGeometry_5();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_5(); }

  private native void Render_6(vtkRenderer id0,vtkMapper id1);
  public void Render(vtkRenderer id0,vtkMapper id1)
    { Render_6(id0,id1); }

  private native void ShallowCopy_7(vtkProp id0);
  public void ShallowCopy(vtkProp id0)
    { ShallowCopy_7(id0); }

  private native void ReleaseGraphicsResources_8(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_8(id0); }

  private native void SetProperty_9(vtkProperty id0);
  public void SetProperty(vtkProperty id0)
    { SetProperty_9(id0); }

  private native long GetProperty_10();
  public vtkProperty GetProperty() {
    long temp = GetProperty_10();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long MakeProperty_11();
  public vtkProperty MakeProperty() {
    long temp = MakeProperty_11();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetBackfaceProperty_12(vtkProperty id0);
  public void SetBackfaceProperty(vtkProperty id0)
    { SetBackfaceProperty_12(id0); }

  private native long GetBackfaceProperty_13();
  public vtkProperty GetBackfaceProperty() {
    long temp = GetBackfaceProperty_13();

    if (temp == 0) return null;
    return (vtkProperty)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetTexture_14(vtkTexture id0);
  public void SetTexture(vtkTexture id0)
    { SetTexture_14(id0); }

  private native long GetTexture_15();
  public vtkTexture GetTexture() {
    long temp = GetTexture_15();

    if (temp == 0) return null;
    return (vtkTexture)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetMapper_16(vtkMapper id0);
  public void SetMapper(vtkMapper id0)
    { SetMapper_16(id0); }

  private native long GetMapper_17();
  public vtkMapper GetMapper() {
    long temp = GetMapper_17();

    if (temp == 0) return null;
    return (vtkMapper)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetBounds_18(double id0[]);
  public void GetBounds(double id0[])
    { GetBounds_18(id0); }

  private native double[] GetBounds_19();
  public double[] GetBounds()
    { return GetBounds_19(); }

  private native void ApplyProperties_20();
  public void ApplyProperties()
    { ApplyProperties_20(); }

  private native int GetMTime_21();
  public int GetMTime()
    { return GetMTime_21(); }

  private native int GetRedrawMTime_22();
  public int GetRedrawMTime()
    { return GetRedrawMTime_22(); }

  private native boolean GetForceOpaque_23();
  public boolean GetForceOpaque()
    { return GetForceOpaque_23(); }

  private native void SetForceOpaque_24(boolean id0);
  public void SetForceOpaque(boolean id0)
    { SetForceOpaque_24(id0); }

  private native void ForceOpaqueOn_25();
  public void ForceOpaqueOn()
    { ForceOpaqueOn_25(); }

  private native void ForceOpaqueOff_26();
  public void ForceOpaqueOff()
    { ForceOpaqueOff_26(); }

  private native boolean GetForceTranslucent_27();
  public boolean GetForceTranslucent()
    { return GetForceTranslucent_27(); }

  private native void SetForceTranslucent_28(boolean id0);
  public void SetForceTranslucent(boolean id0)
    { SetForceTranslucent_28(id0); }

  private native void ForceTranslucentOn_29();
  public void ForceTranslucentOn()
    { ForceTranslucentOn_29(); }

  private native void ForceTranslucentOff_30();
  public void ForceTranslucentOff()
    { ForceTranslucentOff_30(); }

  private native boolean GetSupportsSelection_31();
  public boolean GetSupportsSelection()
    { return GetSupportsSelection_31(); }

  public vtkActor() { super(); }

  public vtkActor(long id) { super(id); }
  public native long   VTKInit();

}
